@@ -1,5 +1,5 @@
 from django.db.models import Model as djangoModel
-from django.core.exceptions import ObjectDoesNotExist
+from django.core.exceptions import ObjectDoesNotExist, MultipleObjectsReturned
 
 
 class FieldError(ValueError):
